﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Xamarin.Forms;
using System.Runtime.CompilerServices;
using System.Runtime.Serialization;

namespace TreeMap
{
    public partial class MainPage : ContentPage
    {     
        public MainPage()
        {
            InitializeComponent();
        }
    }

    public class Summary : INotifyPropertyChanged
    {

        private string _division;
        private string _zone;
        private string _region;
        private string _hq;

        private decimal _svalue;
        private decimal _growth;
        private decimal _target;
        private decimal _qty;
        private decimal _fovalue;
        private decimal _netsales;

        public event PropertyChangedEventHandler PropertyChanged;

        void OnPropertyChanged([CallerMemberName] string propertyName = "") =>
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));

        [DataMember]
        public string Division
        {
            get
            {
                return _division;
            }
            set
            {
                _division = value;
                OnPropertyChanged();
            }
        }

        [DataMember]
        public string Zone
        {
            get
            {
                return _zone;
            }
            set
            {
                _zone = value;
                OnPropertyChanged();
            }
        }

        [DataMember]
        public string Region
        {
            get
            {
                return _region;
            }
            set
            {
                _region = value;
                OnPropertyChanged();
            }
        }
        [DataMember]
        public string Territory
        {
            get
            {
                return _hq;
            }
            set
            {
                _hq = value;
                OnPropertyChanged();
            }
        }

        [DataMember]
        public decimal Target_CurrYear
        {

            get
            {
                return _target;
            }
            set
            {
                _target = value;
                OnPropertyChanged();
            }

        }


        [DataMember]
        public decimal GrossSales_CurrYear
        {
            get
            {
                return _svalue;
            }
            set
            {
                _svalue = value;
                OnPropertyChanged();
            }
        }




        [DataMember]
        public decimal Growth
        {
            get
            {
                return Math.Round(_growth, 0);
            }
            set
            {
                _growth = value;
                OnPropertyChanged();
            }
        }

        public long AchievementPCT
        {
            get
            {
                return Convert.ToInt64(System.Math.Round((_netsales / _target) * 100, 0));
            }
        }

        public string FreeOfferPCT
        {
            get
            {
                if (_svalue == 0)
                {
                    return "0" + "%";
                }
                else
                {
                    return Convert.ToString(System.Math.Round((_fovalue / _svalue) * 100, 0)) + "%";
                }
            }
        }

    }

    public class SummaryViewModel
    {
        public ObservableCollection<Summary> SalesDetails { get; set; }
        public SummaryViewModel()
        {
            this.SalesDetails = new ObservableCollection<Summary>();

            SalesDetails.Add(new Summary() { Division = "Cardiology", Zone = "South", Region = "Chennai", Territory = "Adayar", Growth = 59 });
            SalesDetails.Add(new Summary() { Division = "Cardiology", Zone = "South", Region = "Chennai", Territory = "Anna Nagar", Growth = 75 });
            SalesDetails.Add(new Summary() { Division = "Cardiology", Zone = "South", Region = "Bangalore", Territory = "Bangalore City", Growth = 63 });
            SalesDetails.Add(new Summary() { Division = "Cardiology", Zone = "North", Region = "Delhi", Territory = "New Delhi", Growth = 77 });
            SalesDetails.Add(new Summary() { Division = "Neurology", Zone = "South", Region = "Chennai", Territory = "Preambur", Growth = 85 });
            SalesDetails.Add(new Summary() { Division = "Neurology", Zone = "East", Region = "Vishakapattinam", Territory = "Vishag", Growth = 79 });
            SalesDetails.Add(new Summary() { Division = "Dermatology", Zone = "South", Region = "Chennai", Territory = "Guindy", Growth = 65 });
            SalesDetails.Add(new Summary() { Division = "Dermatology", Zone = "South", Region = "Bangalore", Territory = "Bangalore City", Growth = 73 });
            SalesDetails.Add(new Summary() { Division = "Opthometric", Zone = "South", Region = "Chennai", Territory = "Tambaram", Growth = 56 });
            SalesDetails.Add(new Summary() { Division = "Opthometric", Zone = "West", Region = "Gujarat", Territory = "Gandhi Nagar", Growth = 80 });
            SalesDetails.Add(new Summary() { Division = "Opthometric", Zone = "West", Region = "Mumbai", Territory = "Thane", Growth = 88 });
        }
    }

}
